==> cltk-0.0.1.12.tar.gz: cltk-0.0.1.12/cltk/stem/lemma.py <==
"""Lemmatize Latin words."""

__author__ = 'Kyle P. Johnson <kyle@kyle-p-johnson.com>'
__license__ = 'MIT License. See LICENSE.'

import importlib.machinery
import os
import re

from cltk.utils.cltk_logger import logger


AVAILABLE_LANGUAGES = ['latin']


class LemmaReplacer(object):  # pylint: disable=R0903
    """Lemmatize Latin words by replacing input words with corresponding
    values from a replacement list.
    TODO: this is broken. Need to change the way that the lemma file gets imported.
    rm the tar and turn the 250MB file into 5 50MB, then join them here.
    """

    def __init__(self, language):
        """Import replacement patterns into a list."""
        self.language = language
        self._patterns = self._setup_language_variables()

    def _setup_language_variables(self):
        """Check for availability of lemmatizer for a language.
        TODO: Turn 'lemma_list' file a simple csv and importing on the fly.
        """
        assert self.language in AVAILABLE_LANGUAGES, \
            'Corpora not available for {0} language.'.format(self.language)
        if self.language == 'latin':
            rel_path = os.path.join('~/cltk_data',
                                    self.language,
                                    'trained_model/cltk_linguistic_data/lemmata/lemma_list.py')  # pylint: disable=C0301
            path = os.path.expanduser(rel_path)
            logger.info('Loading lemmata. This may take a minute.')
            loader = importlib.machinery.SourceFileLoader('lemma_list', path)
            module = loader.load_module()
            patterns = module.REPLACEMENT_PATTERNS
        return [(re.compile(regex), repl) for (regex, repl) in patterns]

    def lemmatize(self, text):
        """Replacer of text via the dict.
        :type text: str
        :param text: Input text to be lemmatized.
        :rtype : str
        """
        for (pattern, repl) in self._patterns:
            text = re.subn(pattern, repl, text)[0]
        return text

==> cltk-0.0.1.13.tar.gz: cltk-0.0.1.13/cltk/stem/lemma.py <==
"""Lemmatize Latin words."""

__author__ = 'Kyle P. Johnson <kyle@kyle-p-johnson.com>'
__license__ = 'MIT License. See LICENSE.'

import importlib.machinery
import os
import re

from cltk.utils.cltk_logger import logger


AVAILABLE_LANGUAGES = ['latin']


class LemmaReplacer(object):  # pylint: disable=R0903
    """Lemmatize Latin words by replacing input words with corresponding
    values from a replacement list.
    """

    def __init__(self, language):
        """Import replacement patterns into a list."""
        self.language = language
        self._patterns = self._setup_language_variables()

    def _setup_language_variables(self):
        """Check for availability of lemmatizer for a language.
        TODO: Turn 'lemma_list' file a simple csv and importing on the fly.
        """
        assert self.language in AVAILABLE_LANGUAGES, \
            'Corpora not available for {0} language.'.format(self.language)
        if self.language == 'latin':
            rel_path = os.path.join('~/cltk_data',
                                    self.language,
                                    'model/latin_models_cltk/lemmata/lemma_list.py')  # pylint: disable=C0301
            path = os.path.expanduser(rel_path)
            logger.info('Loading lemmata. This may take a minute.')
            loader = importlib.machinery.SourceFileLoader('lemma_list', path)
            module = loader.load_module()
            patterns = module.REPLACEMENT_PATTERNS
        return [(re.compile(regex), repl) for (regex, repl) in patterns]

    def lemmatize(self, text):
        """Replacer of text via the dict.
        :type text: str
        :param text: Input text to be lemmatized.
        :rtype : str
        """
        for (pattern, repl) in self._patterns:
            text = re.subn(pattern, repl, text)[0]
        return text
